/*******************************************
 *
 * $GAMGI/src/engine/gamgi_engine_number.h
 *
 * Copyright (C) 2001, 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * external functions *
 **********************/

/********
 * text *
 ********/

unsigned int gamgi_engine_number_text_get (void);

void gamgi_engine_number_text_recycle (unsigned int number);

void gamgi_engine_number_text_reset (void); 

/***********
 * orbital *
 ***********/

unsigned int gamgi_engine_number_orbital_get (void);

void gamgi_engine_number_orbital_recycle (unsigned int number);

void gamgi_engine_number_orbital_reset (void); 

/********
 * bond *
 ********/

unsigned int gamgi_engine_number_bond_get (void);

void gamgi_engine_number_bond_recycle (unsigned int number);

void gamgi_engine_number_bond_reset (void); 

/********
 * atom *
 ********/

unsigned int gamgi_engine_number_atom_get (void);

void gamgi_engine_number_atom_recycle (unsigned int number);

void gamgi_engine_number_atom_reset (void); 

/*************
 * direction *
 *************/

unsigned int gamgi_engine_number_direction_get (void);

void gamgi_engine_number_direction_recycle (unsigned int number);

void gamgi_engine_number_direction_reset (void);

/*********
 * plane *
 *********/

unsigned int gamgi_engine_number_plane_get (void);

void gamgi_engine_number_plane_recycle (unsigned int number);

void gamgi_engine_number_plane_reset (void); 

/*********
 * group *
 *********/

unsigned int gamgi_engine_number_group_get (void);

void gamgi_engine_number_group_recycle (unsigned int number);

void gamgi_engine_number_group_reset (void); 

/************
 * molecule *
 ************/

unsigned int gamgi_engine_number_molecule_get (void);

void gamgi_engine_number_molecule_recycle (unsigned int number);

void gamgi_engine_number_molecule_reset (void); 

/***********
 * cluster *
 ***********/

unsigned int gamgi_engine_number_cluster_get (void);

void gamgi_engine_number_cluster_recycle (unsigned int number);

void gamgi_engine_number_cluster_reset (void);

/********
 * cell *
 ********/

unsigned int gamgi_engine_number_cell_get (void);

void gamgi_engine_number_cell_recycle (unsigned int number);

void gamgi_engine_number_cell_reset (void); 

/*********
 * arrow *
 *********/

unsigned int gamgi_engine_number_arrow_get (void);

void gamgi_engine_number_arrow_recycle (unsigned int number);

void gamgi_engine_number_arrow_reset (void);

/*********
 * shape *
 *********/

unsigned int gamgi_engine_number_shape_get (void);

void gamgi_engine_number_shape_recycle (unsigned int number);

void gamgi_engine_number_shape_reset (void); 

/*********
 * graph *
 *********/

unsigned int gamgi_engine_number_graph_get (void);

void gamgi_engine_number_graph_recycle (unsigned int number);

void gamgi_engine_number_graph_reset (void); 

/************
 * assembly *
 ************/

unsigned int gamgi_engine_number_assembly_get (void);

void gamgi_engine_number_assembly_recycle (unsigned int number);

void gamgi_engine_number_assembly_reset (void); 

/*********
 * light *
 *********/

unsigned int gamgi_engine_number_light_get (void);

void gamgi_engine_number_light_recycle (unsigned int number);

void gamgi_engine_number_light_reset (void); 

/*********
 * layer *
 *********/

unsigned int gamgi_engine_number_layer_get (void);

void gamgi_engine_number_layer_recycle (unsigned int number);

void gamgi_engine_number_layer_reset (void); 

/**********
 * window *
 **********/

unsigned int gamgi_engine_number_window_get (void);

void gamgi_engine_number_window_recycle (unsigned int number);

void gamgi_engine_number_window_reset (void); 

/*************
 * Rationale *
 *************



 *************
 * Rationale *
 *************/
